# AG-Spiel API für Python

Die ultimative Python API für das [AG-Spiel](http://www.ag-spiel.de/?bonus=83275). Made by KingKevin23.

## Inhaltsverzeichnis

* [Features](#features)
* [Installation](#installation) 
* [Hinweise](#hinweise)

### Features:

* Orders erstellen

### Installation:

`pip install agspiel-python-api`

### Hinweise:

Diese API oder dieses Projekt stehen in keinerlei Verbindung mit dem Betreiber des Spiels, sondern stellen ein
unabhängiges Userprojekt dar. Desweiten müssen bei allen Projekten, die durch diese API ermöglicht werden oder in denen
diese API eingesetzt wird, die [offiziellen Regeln](https://www.ag-spiel.de/index.php?section=regeln) des AG-Spiels 
beachtet werden. Hierzu zählt insbesondere §5, der im folgenden nochmals zitiert wird:

> Das Benutzen von Programmen/Bots, die einen Spielvorteil ermöglichen, Funktionen bieten die sich mit Premiumfeatures 
> überschneiden oder hohe Serverbelastungen erzeugen (z.B. Parsen der Seite mit mehr als einem Aufruf pro Sekunde), 
> ist verboten. Die Bewerbung/Verbreitung von Browserplugins oder anderer clientseitiger Software zur 
> Erweiterung/Veränderung der Webseite ist verboten.

Bei Fragen zur Legalität des persönlichen Projektes mit dieser API, sollte man sich im Zweifel an die Börsenaufsicht des
AGS wenden ([Hier](https://www.ag-spiel.de/index.php?section=support)).
